==> sceptre-00.317.tar.gz: x3/ngp_gnu.f <==
      PROGRAM NGP_GNU

C  Author  : copyright 1992-2000 by Wolf-Rainer Novender
C  Date    : 11-APR-95
C  Remarks : program to generate graphics from direct acces file data
C            using GNUPLOT
C  Update  : new organization of device selection (ngp.rc) (95.295)

      PARAMETER (NDIM=50000,NWR=6,NIN=5,MAXNAM=51,MAXKRV=6,
     &           ngnu1=18,ngnu2=19,ngp0=20)

      intrinsic SYSTEM

      DIMENSION X(NDIM),Y(NDIM)
      CHARACTER WHEADR*792,WCMD*72,WXLAB*8,WNAME(MAXNAM)*8,
     &          WRESRV(MAXNAM)*19,WKEY(8)*8,WOUT*72,WTEXT*72,WTITEL*72,
     &          wklein*26,wgross*26,wxname*8,wfile*20,wdcomp*36,
     &          wdelim*3,wyname*8,wbslsh*1,wdevic*72,whc*72,wgncmd*72
      INTEGER   KTYP(MAXNAM),KLEN(MAXNAM),KADR(MAXNAM),
     *          INDY(MAXKRV)
      REAL      RMIN(MAXNAM),RMAX(MAXNAM),RNBR(8),ROUT,rscale,versio
      LOGICAL   LERROR,lscale,lhc

      DATA      INDY    /0,0,0,0,0,0/
      DATA      WXLAB   /' '/
      DATA      WTITEL  /' '/

      data      wdevic  /'set term dumb'/
      data      whc     /'set term dumb'/
      data      wgncmd  /' '/

      data      wklein  /'abcdefghijklmnopqrstuvwxyz'/
      data      wgross  /'ABCDEFGHIJKLMNOPQRSTUVWXYZ'/
      data      lscale  /.false./
      data      lhc     /.false./
      include 'compiled.inc'
C     data      wdcomp  /'date-compiled'/
      data      versio  /2000.142/

      wbslsh=char(92)
      CALL POS000 ('OPEN',LERROR)
      WRITE (NWR,'('' NGP version '',F9.3,
     & '' (copyright 1992-2000 by WRNovender)'')') versio 
      print *,'Date compiled: ',wdcomp

  700 open (ngp0,form='formatted',file='ngp.rc',status='old',err=709)
  710 read (ngp0,'(a)',end=790) wcmd
      i=index (wcmd,'term:')
      if (i.gt.0) then
         wdevic=wcmd(i+5:)
         print *,'output device: ',wdevic(1:lenoc(wdevic))
         go to 710
      end if    
      i=index (wcmd,'hc:')
      if (i.gt.0) then
         whc=wcmd(i+3:)
         print *,'hardcopy: ',whc(1:lenoc(whc))
         go to 710
      end if
      i=index (wcmd,'cmd:')
      if (i.gt.0) then
         wgncmd=wcmd(i+4:)
         print *,'GNU command: ',wgncmd(1:lenoc(wgncmd))
         go to 710
      end if    
  790 close (ngp0)
  709 continue

      MAXDIR=MAXNAM
      CALL POSDIR (WNAME,KTYP,KLEN,KADR,WRESRV,MAXDIR,LERROR)
      IF (LERROR) THEN
         PRINT *, 'FEHLER 1'
         GO TO 9999
      END IF

      DO 2 I=1,MAXDIR
         IF (WNAME(I).EQ.'DIRECTOR') GO TO 2
         IF (WNAME(I).EQ.'HEADING ') GO TO 2
         IF (WNAME(I).EQ.'ZZZZZZZZ') GO TO 3
         NX=NDIM
         CALL POSRR4 (WNAME(I),X,NX,LERROR)
         IF (LERROR) GO TO 9999
         RMIN(I)=X(NX-1)
         RMAX(I)=X(NX  )
    2 CONTINUE
    3 CONTINUE

      NHDG=LEN(WHEADR)
      CALL POSRC1 ('HEADING',WHEADR,NHDG,LERROR)
      IF (LERROR) then
         wheadr=' '
         go to 10
      end if
      NLINES=NHDG/72
      WRITE (NWR,*)
      DO 1 I=1,NLINES
         WRITE (NWR,'(1X,A)') WHEADR((I-1)*72+1:I*72)
    1 CONTINUE

   10 continue
      WTITEL=WHEADR(1:72)
      DO 410 I=1,MAXDIR
         IF (WNAME(I).EQ.'DIRECTOR') GO TO 410
         IF (WNAME(I).EQ.'HEADING ') GO TO 410
         IF (WNAME(I).EQ.'ZZZZZZZZ') GO TO 420
         WRITE (NWR,
     *   '(1X,I2,1X,A,1X,A,1X,A,I7,1X,1P2E12.4,2X,A)')
     *   I,WNAME(I)(1:6),WNAME(I)(7:7),WNAME(I)(8:8),KLEN(I),
     *   RMIN(I),RMAX(I),WRESRV(I)
  410 CONTINUE
  420 CONTINUE
      WRITE (NWR,'('' enter command:'')')
      READ (NIN,'(A)') WCMD
      NKEY=0
      NNBR=0
      WTEXT=' '
   15 CALL PARS01 (WCMD,WOUT,MTYP,MLEN,ROUT)
      IF (MLEN.EQ.-99) GO TO 100
      IF (MTYP.EQ.  1) WTEXT=WOUT(1:MLEN)
      IF (MTYP.EQ.  2) THEN
         NNBR=NNBR+1
         RNBR(NNBR)=ROUT
      END IF
      IF (MTYP.EQ.  9) THEN
         NKEY=NKEY+1
         WKEY(NKEY)=WOUT(1:MLEN)
      END IF

      GO TO 15

  100 CONTINUE

      IF (NKEY.LE.0) GO TO 10

C Umwandeln von Klein- nach Grossbuchstaben:

      do 112 i=1,nkey
         do 111 j=1,len(wkey(i))
            k=index(wklein,wkey(i)(j:j))
            if (k.gt.0) wkey(i)(j:j)=wgross(k:k)
  111    continue
  112 continue
C Exit or Quit:
      IF (WKEY(1)(1:1).EQ.'E' .or. wkey(1)(1:1).eq.'Q') GO TO 9999
C Terminal type:
      IF (WKEY(1)(1:4).EQ.'TERM') THEN
         wdevic=wtext
         GO TO 10
      END IF
C GNUPLOT command:
      IF (WKEY(1)(1:3).EQ.'CMD') THEN
         wgncmd=wtext
         GO TO 10
      END IF
C X variable:
      IF (WKEY(1)(1:1).EQ.'X' .AND. NNBR.GT.0) THEN
         INDX=NINT(RNBR(1))
         GO TO 10
      END IF
C Y variables:
      IF (WKEY(1)(1:1).EQ.'Y') THEN
         DO 150 I=1,MAXKRV
            IF (I.GT.NNBR) THEN
               INDY(I)=0
             ELSE
               INDY(I)=NINT(RNBR(I))
            END IF
  150    CONTINUE
         GO TO 10
      END IF
C select X und Y variables:
      IF (WKEY(1)(1:1).EQ.'S' .AND. NNBR.GT.1) THEN
         INDX=NINT(RNBR(1))
         do 151 i=1,maxkrv
            IF (I.GT.NNBR-1) THEN
               INDY(I)=0
             ELSE
               INDY(I)=NINT(RNBR(I+1))
            END IF
  151    CONTINUE
         GO TO 10
      END IF
C scale:
      if (wkey(1)(1:5).eq.'SCALE' .and. wkey(2)(1:2).eq.'ON') then
         lscale=.true.
         go to 10
      end if
      if (wkey(1)(1:5).eq.'SCALE' .and. wkey(2)(1:3).eq.'OFF') then
         lscale=.false.
         go to 10
      end if
C list:
      IF (WKEY(1)(1:1).EQ.'L') THEN
         WRITE (NWR,'('' Output device: '',a)') wdevic(1:lenoc(wdevic))
         WRITE (NWR,'('' Hardcopy:      '',a)') whc(1:lenoc(whc))
         WRITE (NWR,'('' GNU command:   '',a)') wgncmd(1:lenoc(wgncmd))
         WRITE (NWR,'('' X variable   :'')')
         IF (INDX.GT.0)
     *      WRITE (NWR,'(1X,I3,1X,A,1X,1P2E12.4)')
     *         INDX,WNAME(INDX),RMIN(INDX),RMAX(INDX)
         WRITE (NWR,'('' Y variable(s):'')')
         DO 160 I=1,MAXKRV
            IF (INDY(I).EQ.0) GO TO 161
            rscale=1.0
            if (lscale)
     *         rscale=1.0/(max(abs(rmax(indy(i))),abs(rmin(indy(i)))))
            WRITE (NWR,'(1X,I3,1X,A,1X,1P3E12.4)')
     *      INDY(I),WNAME(INDY(I)),RMIN(INDY(I)),RMAX(INDY(I)),rscale
  160    CONTINUE
         write (nwr,*)
  161    CONTINUE
         GO TO 420
      END IF
C draw or plot:
      IF (WKEY(1)(1:1).EQ.'D' .or. wkey(1)(1:1).eq.'P') THEN
         lhc=.false.
         go to 1000
      end if
C Hard Copy:
      if (wkey(1)(1:2).eq.'HC') then
         lhc=.true.
         go to 1000
      end if
C unknown command:      
      WRITE (NWR,'(''0unknown command:'',A)') WCMD
      GO TO 10

C create plot:

 1000 continue

         IF (INDX.EQ.0) THEN
            WRITE (NWR,'('' X variable is missing !!!'')')
            GO TO 10
         END IF
         IF (INDY(1).EQ.0) THEN
            WRITE (NWR,'('' Y variable is missing !!!'')')
            GO TO 10
         END IF

         WXLAB=WNAME(INDX)(1:6)

         open (ngnu2,form='formatted',file='temp.GNU',
     &      status='unknown')
         if (lhc) then
            write (ngnu2,'(a)') whc
          else
            write (ngnu2,'(a)') wdevic(1:lenoc(wdevic))
         end if
         write (ngnu2,602) wxlab(1:lenoc(wxlab))
  602    format('set xlabel ''',a,'''')

C title causes troubles if it contains "
         write (ngnu2,603) wtitel(1:lenoc(wtitel))
  603    format('set title  ''',a,'''')

         write (ngnu2,'(a)') wgncmd(1:lenoc(wgncmd))

         write (ngnu2,'(''plot '',a)') wbslsh

         DO 220 I=1,MAXKRV
            IF (INDY(I).EQ.0) GO TO 221
            NX=NDIM
            wyname=wname(indy(i))
            wxname=WNAME(INDX)(1:7)//wyname(8:8)
            CALL POSRR4 (wxname,X,NX,LERROR)
            IF (LERROR) GO TO 10
            NY=NDIM
            CALL POSRR4 (wyname,Y,NY,LERROR)
            IF (LERROR) GO TO 10
            IF (NX.NE.NY) THEN
               WRITE (NWR,'(''0nx.ne.ny:'',2I8)') NX,NY
               GO TO 10
            END IF

            write (wfile,'(a,a,''.'',a,''.GNU'')')
     &         wyname(1:lenoc(wyname(1:6))),wyname(7:8),
     &         wxname(1:lenoc(wxname(1:6)))
            open (ngnu1,form='formatted',file=wfile(1:lenoc(wfile)),
     &         status='unknown')
            write(ngnu1,'(''#gnuplot:'',a,'' vs '',a)')
     &         wyname,wxname
            wdelim=', '//wbslsh
            if (i.eq.maxkrv .or. indy(i+1).eq.0) wdelim=' '
            write(ngnu2,611) wfile(1:lenoc(wfile)),
     &         wyname(1:lenoc(wyname(1:6)))//'('//wyname(8:8)//')',
     &         wdelim
  611       format('''',a,''' title ''',a,''' with lines',a)
            rscale=1.0
            if (lscale)
     *         rscale=1.0/(max(abs(rmax(indy(i))),abs(rmin(indy(i)))))
            do 217 j=1,nx-2
               write (ngnu1,'(1x,1p,2E12.4)') x(j),y(j)*rscale
  217       continue 
            close (ngnu1)
            write (nwr,'(a,'' created'')') wfile(1:lenoc(wfile))

  220    CONTINUE
  221    CONTINUE

         write(ngnu2,'(''pause -1'')')
         close(ngnu2)
         call system ("gnuplot temp.GNU")

         WXLAB=' '
         GO TO 10
C----------------------------------------------------------------------
 9999 CONTINUE

      STOP

      END

==> sceptre-2012.061.tar.gz: x3/ngp_gnu.f <==
      PROGRAM NGP_GNU

C  Author  : copyright 1992-2009 by Wolf-Rainer Novender
C  Date    : 11-APR-95
C  Remarks : program to generate graphics from direct acces file data
C            using GNUPLOT
C  Update  : new organization of device selection (ngp.rc) (95.295)

      PARAMETER (NDIM=50000,NWR=6,NIN=5,MAXNAM=51,MAXKRV=6,
     &           ngnu1=18,ngnu2=19,ngp0=20)

!      intrinsic SYSTEM

      DIMENSION X(NDIM),Y(NDIM)
      CHARACTER WHEADR*792,WCMD*72,WXLAB*8,WNAME(MAXNAM)*8,
     &          WRESRV(MAXNAM)*19,WKEY(8)*8,WOUT*72,WTEXT*72,WTITEL*72,
     &          wklein*26,wgross*26,wxname*8,wfile*20,wdcomp*36,
     &          wdelim*3,wyname*8,wbslsh*1,wdevic*72,whc*72,wgncmd*72
      INTEGER   KTYP(MAXNAM),KLEN(MAXNAM),KADR(MAXNAM),
     *          INDY(MAXKRV)
      REAL      RMIN(MAXNAM),RMAX(MAXNAM),RNBR(8),ROUT,rscale,Versn
      LOGICAL   LERROR,lscale,lhc

      DATA      INDY    /0,0,0,0,0,0/
      DATA      WXLAB   /' '/
      DATA      WTITEL  /' '/

      data      wdevic  /'set term dumb'/
      data      whc     /'set term dumb'/
      data      wgncmd  /' '/

      data      wklein  /'abcdefghijklmnopqrstuvwxyz'/
      data      wgross  /'ABCDEFGHIJKLMNOPQRSTUVWXYZ'/
      data      lscale  /.false./
      data      lhc     /.false./
      include 'compiled.inc'
C     data      wdcomp  /'date-compiled'/
      include 'version.inc'
C     data      Versn  /2006.202/

      wbslsh=char(92)
      CALL POS000 ('OPEN',LERROR)
      WRITE (NWR,'('' NGP version '',F9.3,
     & '' (copyright 1992-2012 by WRNovender)'')') Versn 
      print *,'Date compiled: ',wdcomp

      open (ngp0,form='formatted',file='ngp.rc',status='old',err=709)
  710 read (ngp0,'(a)',end=790) wcmd
      i=index (wcmd,'term:')
      if (i.gt.0) then
         wdevic=wcmd(i+5:)
         print *,'output device: ',wdevic(1:lenoc(wdevic))
         go to 710
      end if    
      i=index (wcmd,'hc:')
      if (i.gt.0) then
         whc=wcmd(i+3:)
         print *,'hardcopy: ',whc(1:lenoc(whc))
         go to 710
      end if
      i=index (wcmd,'cmd:')
      if (i.gt.0) then
         wgncmd=wcmd(i+4:)
         print *,'GNU command: ',wgncmd(1:lenoc(wgncmd))
         go to 710
      end if    
  790 close (ngp0)
  709 continue

      MAXDIR=MAXNAM
      CALL POSDIR (WNAME,KTYP,KLEN,KADR,WRESRV,MAXDIR,LERROR)
      IF (LERROR) THEN
         PRINT *, 'FEHLER 1'
         GO TO 9999
      END IF

      DO 2 I=1,MAXDIR
         IF (WNAME(I).EQ.'DIRECTOR') GO TO 2
         IF (WNAME(I).EQ.'HEADING ') GO TO 2
         IF (WNAME(I).EQ.'ZZZZZZZZ') GO TO 3
         NX=NDIM
         CALL POSRR4 (WNAME(I),X,NX,LERROR)
         IF (LERROR) GO TO 9999
         RMIN(I)=X(NX-1)
         RMAX(I)=X(NX  )
    2 CONTINUE
    3 CONTINUE

      NHDG=LEN(WHEADR)
      CALL POSRC1 ('HEADING',WHEADR,NHDG,LERROR)
      IF (LERROR) then
         wheadr=' '
         go to 10
      end if
      NLINES=NHDG/72
      WRITE (NWR,*)
      DO 1 I=1,NLINES
         WRITE (NWR,'(1X,A)') WHEADR((I-1)*72+1:I*72)
    1 CONTINUE

   10 continue
      WTITEL=WHEADR(1:72)
      DO 410 I=1,MAXDIR
         IF (WNAME(I).EQ.'DIRECTOR') GO TO 410
         IF (WNAME(I).EQ.'HEADING ') GO TO 410
         IF (WNAME(I).EQ.'ZZZZZZZZ') GO TO 420
         WRITE (NWR,
     *   '(1X,I2,1X,A,1X,A,1X,A,I7,1X,1P2E12.4,2X,A)')
     *   I,WNAME(I)(1:6),WNAME(I)(7:7),WNAME(I)(8:8),KLEN(I),
     *   RMIN(I),RMAX(I),WRESRV(I)
  410 CONTINUE
  420 CONTINUE
      WRITE (NWR,'('' enter command:'')')
      READ (NIN,'(A)') WCMD
      NKEY=0
      NNBR=0
      WTEXT=' '
   15 CALL PARS01 (WCMD,WOUT,MTYP,MLEN,ROUT)
      IF (MLEN.EQ.-99) GO TO 100
      IF (MTYP.EQ.  1) WTEXT=WOUT(1:MLEN)
      IF (MTYP.EQ.  2) THEN
         NNBR=NNBR+1
         RNBR(NNBR)=ROUT
      END IF
      IF (MTYP.EQ.  9) THEN
         NKEY=NKEY+1
         WKEY(NKEY)=WOUT(1:MLEN)
      END IF

      GO TO 15

  100 CONTINUE

      IF (NKEY.LE.0) GO TO 10

C Umwandeln von Klein- nach Grossbuchstaben:

      do 112 i=1,nkey
         do 111 j=1,len(wkey(i))
            k=index(wklein,wkey(i)(j:j))
            if (k.gt.0) wkey(i)(j:j)=wgross(k:k)
  111    continue
  112 continue
C Exit or Quit:
      IF (WKEY(1)(1:1).EQ.'E' .or. wkey(1)(1:1).eq.'Q') GO TO 9999
C Terminal type:
      IF (WKEY(1)(1:4).EQ.'TERM') THEN
         wdevic=wtext
         GO TO 10
      END IF
C GNUPLOT command:
      IF (WKEY(1)(1:3).EQ.'CMD') THEN
         wgncmd=wtext
         GO TO 10
      END IF
C X variable:
      IF (WKEY(1)(1:1).EQ.'X' .AND. NNBR.GT.0) THEN
         INDX=NINT(RNBR(1))
         GO TO 10
      END IF
C Y variables:
      IF (WKEY(1)(1:1).EQ.'Y') THEN
         DO 150 I=1,MAXKRV
            IF (I.GT.NNBR) THEN
               INDY(I)=0
             ELSE
               INDY(I)=NINT(RNBR(I))
            END IF
  150    CONTINUE
         GO TO 10
      END IF
C select X und Y variables:
      IF (WKEY(1)(1:1).EQ.'S' .AND. NNBR.GT.1) THEN
         INDX=NINT(RNBR(1))
         do 151 i=1,maxkrv
            IF (I.GT.NNBR-1) THEN
               INDY(I)=0
             ELSE
               INDY(I)=NINT(RNBR(I+1))
            END IF
  151    CONTINUE
         GO TO 10
      END IF
C scale:
      if (wkey(1)(1:5).eq.'SCALE' .and. wkey(2)(1:2).eq.'ON') then
         lscale=.true.
         go to 10
      end if
      if (wkey(1)(1:5).eq.'SCALE' .and. wkey(2)(1:3).eq.'OFF') then
         lscale=.false.
         go to 10
      end if
C list:
      IF (WKEY(1)(1:1).EQ.'L') THEN
         WRITE (NWR,'('' Output device: '',a)') wdevic(1:lenoc(wdevic))
         WRITE (NWR,'('' Hardcopy:      '',a)') whc(1:lenoc(whc))
         WRITE (NWR,'('' GNU command:   '',a)') wgncmd(1:lenoc(wgncmd))
         WRITE (NWR,'('' X variable   :'')')
         IF (INDX.GT.0)
     *      WRITE (NWR,'(1X,I3,1X,A,1X,1P2E12.4)')
     *         INDX,WNAME(INDX),RMIN(INDX),RMAX(INDX)
         WRITE (NWR,'('' Y variable(s):'')')
         DO 160 I=1,MAXKRV
            IF (INDY(I).EQ.0) GO TO 161
            rscale=1.0
            if (lscale)
     *         rscale=1.0/(max(abs(rmax(indy(i))),abs(rmin(indy(i)))))
            WRITE (NWR,'(1X,I3,1X,A,1X,1P3E12.4)')
     *      INDY(I),WNAME(INDY(I)),RMIN(INDY(I)),RMAX(INDY(I)),rscale
  160    CONTINUE
         write (nwr,*)
  161    CONTINUE
         GO TO 420
      END IF
C draw or plot:
      IF (WKEY(1)(1:1).EQ.'D' .or. wkey(1)(1:1).eq.'P') THEN
         lhc=.false.
         go to 1000
      end if
C Hard Copy:
      if (wkey(1)(1:2).eq.'HC') then
         lhc=.true.
         go to 1000
      end if
C unknown command:      
      WRITE (NWR,'(''0unknown command:'',A)') WCMD
      GO TO 10

C create plot:

 1000 continue

         IF (INDX.EQ.0) THEN
            WRITE (NWR,'('' X variable is missing !!!'')')
            GO TO 10
         END IF
         IF (INDY(1).EQ.0) THEN
            WRITE (NWR,'('' Y variable is missing !!!'')')
            GO TO 10
         END IF

         WXLAB=WNAME(INDX)(1:6)

         open (ngnu2,form='formatted',file='temp.gpi',
     &      status='unknown')
         if (lhc) then
            write (ngnu2,'(a)') whc
          else
            write (ngnu2,'(a)') wdevic(1:lenoc(wdevic))
         end if
         write (ngnu2,602) wxlab(1:lenoc(wxlab))
  602    format('set xlabel ''',a,'''')

C title causes troubles if it contains "
         write (ngnu2,603) wtitel(1:lenoc(wtitel))
  603    format('set title  ''',a,'''')

         write (ngnu2,'(a)') wgncmd(1:lenoc(wgncmd))

         write (ngnu2,'(''plot '',a)') wbslsh

         DO 220 I=1,MAXKRV
            IF (INDY(I).EQ.0) GO TO 221
            NX=NDIM
            wyname=wname(indy(i))
            wxname=WNAME(INDX)(1:7)//wyname(8:8)
            CALL POSRR4 (wxname,X,NX,LERROR)
            IF (LERROR) GO TO 10
            NY=NDIM
            CALL POSRR4 (wyname,Y,NY,LERROR)
            IF (LERROR) GO TO 10
            IF (NX.NE.NY) THEN
               WRITE (NWR,'(''0nx.ne.ny:'',2I8)') NX,NY
               GO TO 10
            END IF

            write (wfile,'(a,a,''.'',a,''.GPI'')')
     &         wyname(1:lenoc(wyname(1:6))),wyname(7:8),
     &         wxname(1:lenoc(wxname(1:6)))
            open (ngnu1,form='formatted',file=wfile(1:lenoc(wfile)),
     &         status='unknown')
            write(ngnu1,'(''#gnuplot:'',a,'' vs '',a)')
     &         wyname,wxname
            wdelim=', '//wbslsh
            if (i.eq.maxkrv .or. indy(i+1).eq.0) wdelim=' '
            write(ngnu2,611) wfile(1:lenoc(wfile)),
     &         wyname(1:lenoc(wyname(1:6)))//'('//wyname(8:8)//')',
     &         wdelim
  611       format('''',a,''' title ''',a,''' with lines lw 3',a)
            rscale=1.0
            if (lscale)
     *         rscale=1.0/(max(abs(rmax(indy(i))),abs(rmin(indy(i)))))
            do 217 j=1,nx-2
               write (ngnu1,'(1x,1p,2E12.4)') x(j),y(j)*rscale
  217       continue 
            close (ngnu1)
            write (nwr,'(a,'' created'')') wfile(1:lenoc(wfile))

  220    CONTINUE
  221    CONTINUE

         write(ngnu2,'(''pause -1'')')
         close(ngnu2)
         call system ("gnuplot temp.gpi")

         WXLAB=' '
         GO TO 10
C----------------------------------------------------------------------
 9999 CONTINUE

      STOP

      END
